@@ -30,4 +30,12 @@
 # endif
 #endif
 
+#ifndef GIRARA_DEPRECATED
+# if defined(__GNUC__)
+#  define GIRARA_DEPRECATED(x) x __attribute__((deprecated))
+# else
+#  define GIRARA_DEPRECATED(x) x
+# endif
+#endif
+
 #endif
