@@ -22,11 +22,13 @@ cb_window_icon(girara_session_t* session, const char* UNUSED(name), girara_setti
 {
   g_return_if_fail(session != NULL && value != NULL);
 
-  GError* error = NULL;
-  gtk_window_set_icon_from_file(GTK_WINDOW(session->gtk.window), (const char*) value, &error);
-  if (error != NULL) {
-    girara_error("failed to load window icon: %s", error->message);
-    g_error_free(error);
+  if (session->gtk.window != NULL) {
+    GError* error = NULL;
+    gtk_window_set_icon_from_file(GTK_WINDOW(session->gtk.window), (const char*) value, &error);
+    if (error != NULL) {
+      girara_error("failed to load window icon: %s", error->message);
+      g_error_free(error);
+    }
   }
 }
 
@@ -198,7 +200,7 @@ girara_session_init(girara_session_t* session, const char* sessionname)
   } else {
     session->gtk.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   }
-  if (sessionname) {
+  if (sessionname != NULL) {
     gtk_widget_set_name(GTK_WIDGET(session->gtk.window), sessionname);
   }
 
@@ -358,7 +360,7 @@ girara_session_init(girara_session_t* session, const char* sessionname)
   for (unsigned i = 0; i < LENGTH(color_setting_mappings); i++) {
     char* tmp_value = NULL;
     girara_setting_get(session, color_setting_mappings[i].identifier, &tmp_value);
-    if (tmp_value) {
+    if (tmp_value != NULL) {
       gdk_rgba_parse(color_setting_mappings[i].color, tmp_value);
       g_free(tmp_value);
     }
@@ -374,12 +376,15 @@ girara_session_init(girara_session_t* session, const char* sessionname)
 
   /* inputbar */
 #if (GTK_MAJOR_VERSION == 3)
+  gtk_widget_override_background_color(GTK_WIDGET(session->gtk.inputbar_entry),
+      GTK_STATE_NORMAL, &(session->style.inputbar_background));
+  gtk_widget_override_color(GTK_WIDGET(session->gtk.inputbar_entry),
+      GTK_STATE_NORMAL, &(session->style.inputbar_foreground));
+
   gtk_widget_override_background_color(GTK_WIDGET(session->gtk.inputbar),
       GTK_STATE_NORMAL, &(session->style.inputbar_background));
   gtk_widget_override_color(GTK_WIDGET(session->gtk.inputbar_dialog),
       GTK_STATE_NORMAL, &(session->style.inputbar_foreground));
-  gtk_widget_override_background_color(GTK_WIDGET(session->gtk.inputbar_entry),
-      GTK_STATE_NORMAL, &(session->style.inputbar_background));
 
   /* notification area */
   gtk_widget_override_background_color(GTK_WIDGET(session->gtk.notification_area),
@@ -416,7 +421,7 @@ girara_session_init(girara_session_t* session, const char* sessionname)
   girara_setting_get(session, "window-width", &window_width);
   girara_setting_get(session, "window-height", &window_height);
 
-  if (window_width && window_height) {
+  if (window_width > 0&& window_height > 0) {
     gtk_window_set_default_size(GTK_WINDOW(session->gtk.window), window_width, window_height);
   }
 
@@ -425,6 +430,15 @@ girara_session_init(girara_session_t* session, const char* sessionname)
   gtk_widget_hide(GTK_WIDGET(session->gtk.inputbar));
   gtk_widget_hide(GTK_WIDGET(session->gtk.inputbar_dialog));
 
+  char* window_icon = NULL;
+  girara_setting_get(session, "window-icon", &window_icon);
+  if (window_icon != NULL) {
+    if (strlen(window_icon) != 0) {
+      girara_setting_set(session, "window-icon", window_icon);
+    }
+    g_free(window_icon);
+  }
+
   return TRUE;
 }
 
@@ -655,3 +669,16 @@ girara_mode_get(girara_session_t* session)
 
   return session->modes.current_mode;
 }
+
+bool
+girara_set_window_title(girara_session_t* session, const char* name)
+{
+  if (session == NULL || session->gtk.window == NULL || name == NULL) {
+    return false;
+  }
+
+  gtk_window_set_title(GTK_WINDOW(session->gtk.window), name);
+
+  return true;
+}
+
