@@ -50,7 +50,7 @@ read_pwd_info(void)
     pwdinfo->dir = g_strdup(pw->pw_dir);
     girara_list_append(list, pwdinfo);
   }
-  fail_unless(errno == 0);
+  fail_unless(errno == 0, "Non-zero errno :%d", errno, NULL);
   endpwent();
 
   return list;
@@ -62,23 +62,23 @@ START_TEST(test_home_directory) {
 
   if (oldenv) {
     gchar* result = girara_get_home_directory(NULL);
-    fail_unless(result != oldenv, "Home directory is not the same");
+    fail_unless(result != oldenv, "Home directory is not the same", NULL);
     g_free(result);
   }
 
   g_unsetenv("HOME");
   gchar* result = girara_get_home_directory(NULL);
-  fail_unless(result != user, "Home directory is not the same");
+  fail_unless(result != user, "Home directory is not the same", NULL);
   g_free(result);
 
   girara_list_t* list = read_pwd_info();
   girara_list_iterator_t* iter = girara_list_iterator(list);
-  fail_unless(iter != NULL, "Could not create iterator");
+  fail_unless(iter != NULL, "Could not create iterator", NULL);
   while (girara_list_iterator_is_valid(iter))
   {
     pwd_info_t* pwdinfo = (pwd_info_t*) girara_list_iterator_data(iter);
     gchar* result = girara_get_home_directory(pwdinfo->name);
-    fail_unless(result != pwdinfo->dir, "Home directory is not the same");
+    fail_unless(result != pwdinfo->dir, "Home directory is not the same", NULL);
     g_free(result);
     girara_list_iterator_next(iter);
   }
@@ -87,7 +87,7 @@ START_TEST(test_home_directory) {
 
   g_setenv("HOME", "/home/test", TRUE);
   result = girara_get_home_directory(NULL);
-  fail_unless(g_strcmp0(result, "/home/test") == 0, "Home directory is not the same");
+  fail_unless(g_strcmp0(result, "/home/test") == 0, "Home directory is not the same", NULL);
   g_free(result);
 
   if (oldenv) {
@@ -96,22 +96,27 @@ START_TEST(test_home_directory) {
   }
 } END_TEST
 
-START_TEST(test_fix_path) {
+START_TEST(test_fix_path_basic) {
   gchar* result = girara_fix_path("test");
-  fail_unless(g_strcmp0(result, "test") == 0, "Fix path result does not match");
+  fail_unless(g_strcmp0(result, "test") == 0,
+      "Fix path result does not match (got: %s, expected: %s)", result, "test", NULL);
   g_free(result);
 
   result = girara_fix_path("test/test");
-  fail_unless(g_strcmp0(result, "test/test") == 0, "Fix path result does not match");
+  fail_unless(g_strcmp0(result, "test/test") == 0,
+      "Fix path result does not match (got: %s, expected: %s)", result, "test/test", NULL);
   g_free(result);
+} END_TEST
 
+START_TEST(test_fix_path_extended) {
   girara_list_t* list = read_pwd_info();
   GIRARA_LIST_FOREACH(list, pwd_info_t*, iter, pwdinfo)
     gchar* path = g_strdup_printf("~%s/test", pwdinfo->name);
     gchar* eres = g_build_filename(pwdinfo->dir, "test", NULL);
 
     gchar* result = girara_fix_path(path);
-    fail_unless(g_strcmp0(result, eres) == 0, "Fix path result does not match");
+    fail_unless(g_strcmp0(result, eres) == 0,
+        "Fix path result does not match (got: %s, expected %s)", result, eres, NULL);
     g_free(result);
     g_free(eres);
     g_free(path);
@@ -130,7 +135,8 @@ xdg_path_impl(girara_xdg_path_t path, const gchar* envvar,
   bool result = g_spawn_sync(NULL, argv, envp, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &output, NULL, NULL, NULL);
   g_assert(result);
   g_assert(output);
-  fail_unless(g_strcmp0(output, expected) == 0, "Output is not the same");
+  fail_unless(g_strcmp0(output, expected) == 0, "Output is not the same (got: %s, expected: %s)",
+      output, expected, NULL);
   g_free(output);
 
   g_free(envp[0]);
@@ -139,7 +145,8 @@ xdg_path_impl(girara_xdg_path_t path, const gchar* envvar,
   result = g_spawn_sync(NULL, argv, envp, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &output, NULL, NULL, NULL);
   g_assert(result);
   g_assert(output);
-  fail_unless(g_strcmp0(output, "~/xdg") == 0, "Output is not the same");
+  fail_unless(g_strcmp0(output, "~/xdg") == 0, "Output is not the same (got: %s, expected: %s)",
+      output, "~/xdg", NULL);
 
   g_free(envp[0]);
   envp[0] = g_strdup_printf("%s=/home/test/xdg", envvar);
@@ -147,7 +154,8 @@ xdg_path_impl(girara_xdg_path_t path, const gchar* envvar,
   result= g_spawn_sync(NULL, argv, envp, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &output, NULL, NULL, NULL);
   g_assert(result);
   g_assert(output);
-  fail_unless(g_strcmp0(output, "/home/test/xdg") == 0, "Output is not the same");
+  fail_unless(g_strcmp0(output, "/home/test/xdg") == 0, "Output is not the same (got: %s, expected: %s)",
+      output, "/home/test/xdg", NULL);
 
   g_free(argv[1]);
 }
@@ -160,12 +168,12 @@ START_TEST(test_xdg_path) {
 } END_TEST
 
 START_TEST(test_file_invariants) {
-  fail_unless(girara_file_open(NULL, NULL) == NULL);
-  fail_unless(girara_file_open("somefile", NULL) == NULL);
-  fail_unless(girara_file_open(NULL, "r") == NULL);
+  fail_unless(girara_file_open(NULL, NULL) == NULL, NULL);
+  fail_unless(girara_file_open("somefile", NULL) == NULL, NULL);
+  fail_unless(girara_file_open(NULL, "r") == NULL, NULL);
 
-  fail_unless(girara_file_read_line(NULL) == NULL);
-  fail_unless(girara_file_read(NULL) == NULL);
+  fail_unless(girara_file_read_line(NULL) == NULL, NULL);
+  fail_unless(girara_file_read(NULL) == NULL, NULL);
 } END_TEST
 
 START_TEST(test_file_read) {
@@ -175,56 +183,61 @@ START_TEST(test_file_read) {
 
   gchar* path = NULL;
   int fd = g_file_open_tmp("girara.test.XXXXXX", &path, NULL);
-  fail_unless(fd != -1);
-  fail_unless(g_strcmp0(path, "") != 0);
-  close(fd);
+  fail_unless(fd != -1, "Failed to open temporary file.", NULL);
+  fail_unless(g_strcmp0(path, "") != 0, "Failed to open temporary file.", NULL);
 
-  g_assert(g_file_set_contents(path, CONTENT, -1, NULL));
+  GError* error = NULL;
+  if (g_file_set_contents(path, CONTENT, -1, &error) == FALSE) {
+    fail_unless(false, "Couldn't set content: %s", error->message, NULL);
+    g_error_free(error);
+  }
 
   char* content = girara_file_read(path);
-  fail_unless(g_strcmp0(content, CONTENT) == 0);
+  fail_unless(g_strcmp0(content, CONTENT) == 0, "Reading file failed", NULL);
   free(content);
 
   FILE* file = girara_file_open(path, "r");
-  fail_unless(file != NULL);
+  fail_unless(file != NULL, NULL);
   for (size_t i = 0; i != NUMLINES; ++i) {
     char* line = girara_file_read_line(file);
-    fail_unless(g_strcmp0(line, LINES[i]) == 0);
+    fail_unless(g_strcmp0(line, LINES[i]) == 0, "Line doesn't match (got: %s, expected: %s)",
+        line, LINES[i], NULL);
     free(line);
   }
   fclose(file);
 
-  fail_unless(g_remove(path) == 0);
+  close(fd);
+  fail_unless(g_remove(path) == 0, "Failed to remove temporary file.", NULL);
   g_free(path);
 } END_TEST
 
 START_TEST(test_safe_realloc) {
-  fail_unless(girara_safe_realloc(NULL, 0u) == NULL);
+  fail_unless(girara_safe_realloc(NULL, 0u) == NULL, NULL);
 
   void* ptr = NULL;
-  fail_unless(girara_safe_realloc(&ptr, sizeof(int)) != NULL);
-  fail_unless(ptr != NULL);
-  fail_unless(girara_safe_realloc(&ptr, 1024*sizeof(int)) != NULL);
-  fail_unless(ptr != NULL);
-  fail_unless(girara_safe_realloc(&ptr, 0u) == NULL);
-  fail_unless(ptr == NULL);
+  fail_unless(girara_safe_realloc(&ptr, sizeof(int)) != NULL, NULL);
+  fail_unless(ptr != NULL, NULL);
+  fail_unless(girara_safe_realloc(&ptr, 1024*sizeof(int)) != NULL, NULL);
+  fail_unless(ptr != NULL, NULL);
+  fail_unless(girara_safe_realloc(&ptr, 0u) == NULL, NULL);
+  fail_unless(ptr == NULL, NULL);
 } END_TEST
 
 START_TEST(test_split_path) {
-  fail_unless(girara_split_path_array(NULL) == NULL);
-  fail_unless(girara_split_path_array("") == NULL);
+  fail_unless(girara_split_path_array(NULL) == NULL, NULL);
+  fail_unless(girara_split_path_array("") == NULL, NULL);
 
   girara_list_t* res = girara_split_path_array("one/path");
-  fail_unless(res != NULL);
-  fail_unless(girara_list_size(res) == 1);
-  fail_unless(g_strcmp0(girara_list_nth(res, 0), "one/path") == 0);
+  fail_unless(res != NULL, NULL);
+  fail_unless(girara_list_size(res) == 1, NULL);
+  fail_unless(g_strcmp0(girara_list_nth(res, 0), "one/path") == 0, NULL);
   girara_list_free(res);
 
   res = girara_split_path_array("first/path:second/path");
-  fail_unless(res != NULL);
-  fail_unless(girara_list_size(res) == 2);
-  fail_unless(g_strcmp0(girara_list_nth(res, 0), "first/path") == 0);
-  fail_unless(g_strcmp0(girara_list_nth(res, 1), "second/path") == 0);
+  fail_unless(res != NULL, NULL);
+  fail_unless(girara_list_size(res) == 2, NULL);
+  fail_unless(g_strcmp0(girara_list_nth(res, 0), "first/path") == 0, NULL);
+  fail_unless(g_strcmp0(girara_list_nth(res, 1), "second/path") == 0, NULL);
   girara_list_free(res);
 } END_TEST
 
@@ -240,7 +253,8 @@ Suite* suite_utils()
 
   /* fix path */
   tcase = tcase_create("fix_path");
-  tcase_add_test(tcase, test_fix_path);
+  tcase_add_test(tcase, test_fix_path_basic);
+  tcase_add_test(tcase, test_fix_path_extended);
   suite_add_tcase(suite, tcase);
 
   /* xdg path */
