@@ -230,6 +230,31 @@ girara_file_open(const char* path, const char* mode)
   /*return fp;*/
 }
 
+#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+char*
+girara_file_read_line(FILE* file)
+{
+  if (file == NULL) {
+    return NULL;
+  }
+
+  size_t size = 0;
+  char* line = fgetln(file, &size);
+  if (line  == NULL) {
+    return NULL;
+  }
+
+  char* copy = strndup(line, size);
+  if (copy == NULL) {
+    return NULL;
+  }
+
+  /* remove the trailing line deliminator */
+  g_strdelimit(copy, "\n\r", '\0');
+
+  return copy;
+}
+#else
 char*
 girara_file_read_line(FILE* file)
 {
@@ -250,6 +275,7 @@ girara_file_read_line(FILE* file)
   g_strdelimit(line, "\n\r", '\0');
   return line;
 }
+#endif
 
 char*
 girara_file_read(const char* path)
@@ -365,9 +391,18 @@ error_free:
   return NULL;
 }
 
+static girara_debug_level_t debug_level = GIRARA_DEBUG;
+
 void
 _girara_debug(const char* function, int line, girara_debug_level_t level, const char* format, ...)
 {
+  /* This could be simplified if DEBUG, INFO, WARNING, ERROR were ordered. */
+  if ((debug_level == GIRARA_ERROR && level != GIRARA_ERROR) ||
+      (debug_level == GIRARA_WARNING && (level != GIRARA_ERROR && level != GIRARA_WARNING)) ||
+      (debug_level == GIRARA_INFO && level == GIRARA_DEBUG)) {
+    return;
+  }
+
   switch (level)
   {
     case GIRARA_WARNING:
@@ -381,6 +416,7 @@ _girara_debug(const char* function, int line, girara_debug_level_t level, const
       break;
     case GIRARA_DEBUG:
       fprintf(stderr, "debug: (%s:%d) ", function, line);
+      break;
     default:
       return;
   }
@@ -392,3 +428,15 @@ _girara_debug(const char* function, int line, girara_debug_level_t level, const
 
   fprintf(stderr, "\n");
 }
+
+girara_debug_level_t
+girara_get_debug_level()
+{
+  return debug_level;
+}
+
+void
+girara_set_debug_level(girara_debug_level_t level)
+{
+  debug_level = level;
+}
